About
=====

These are GUI dialogs that could be re-used in other glue applications. These
will often be dialogs that allow the user to change the underlying glue state,
for example creating links, editing the data, creating new components.

Each dialog should be included in a directory, and should contain a
sub-directory for each specific GUI framework (e.g. ``qt/``).